LspSemanticToken class

Constructors

LspSemanticToken({required int line, required int start, required int length, required int typeIndex, required int modifierBitmask, String? tokenTypeName})
const

Properties

end → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
final
line → int
final
modifierBitmask → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final
tokenTypeName → String?
The actual token type name from the server's legend (e.g., 'namespace', 'function', etc.) This is populated from the server's semanticTokensProvider.legend.tokenTypes list.
final
typeIndex → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited