enableLocalSuggestions property
Whether to enable local and non LSP autocomplete suggestions.
To control LSP suggestions, use the capabilities field of the LspConfig.
false by default because, this may cause delay or jitter in large files.
Implementation
final bool enableLocalSuggestions;