keyboardShotcuts property
Keyboard shortcuts used by the CodeForge editor.
Most of the keyboard shortcuts, except the core operations like cut, copy, paste, select all, undo, redo
can be modified by editing the hardcoded shortcuts defined in the CodeForgeKeyboardShotcuts class.
eg:
// Here the line duplicate shortcut `Ctrl + D` has beeb overriden by `Ctrl + B`.
CodeForge(
keyboardShotcuts: CodeForgeKeyboardShotcuts(
duplicate: SingleActivator(LogicalKeyboardKey.keyB, control: true)
),
)
Note: There is no exception handling implemented to prevent the usage of same shortcut keys on multiple operations. Using the same shortcut on multiple operations may causes undefined behaviour.
Implementation
final CodeForgeKeyboardShortcuts keyboardShotcuts;