verticalScrollPhysics property

ScrollPhysics verticalScrollPhysics
final

The scroll physics that can be used to modify the vertical scroll behaviour of the editor.
Defaults to ClampingScrollPhysics.
The horizontal scroll physics cannot be modified because CodeForge internally uses a custom scroll physics for RTL support.

Implementation

final ScrollPhysics verticalScrollPhysics;