diagnosticsNotifier property
A ValueNotifier that returns the error, warnings, info, etc from the LSP server.
Implementation
final ValueNotifier<List<LspErrors>> diagnosticsNotifier = ValueNotifier([]);
A ValueNotifier that returns the error, warnings, info, etc from the LSP server.
final ValueNotifier<List<LspErrors>> diagnosticsNotifier = ValueNotifier([]);