requestImeReset property

VoidCallback? requestImeReset
getter/setter pair

Set by the view layer. Invoked when the editor needs the platform input connection hard-reset (close + re-attach) -- e.g. to make the IME drop an in-progress composition and close its candidate window after the caret is moved by a click during composition.

Implementation

VoidCallback? requestImeReset;