selectedSuggestionNotifier property
Returns the index of the selected suggestion from the suggestionsNotifier
Implementation
final ValueNotifier<int?> selectedSuggestionNotifier = ValueNotifier(null);
Returns the index of the selected suggestion from the suggestionsNotifier
final ValueNotifier<int?> selectedSuggestionNotifier = ValueNotifier(null);