delete method
Mutable delete - modifies this rope in place For immutable version, use deleteImmutable
Implementation
void delete(int start, int end) {
_rope.remove(start: BigInt.from(start), end: BigInt.from(end));
}
Mutable delete - modifies this rope in place For immutable version, use deleteImmutable
void delete(int start, int end) {
_rope.remove(start: BigInt.from(start), end: BigInt.from(end));
}