insert method
Mutable insert - modifies this rope in place For immutable version, use insertImmutable
Implementation
void insert(int position, String text) {
_rope.insert(charIdx: BigInt.from(position), text: text);
}
Mutable insert - modifies this rope in place For immutable version, use insertImmutable
void insert(int position, String text) {
_rope.insert(charIdx: BigInt.from(position), text: text);
}