CustomScrollbar class

Inheritance

Constructors

CustomScrollbar({Key? key, required Widget child, required ScrollController? controller, required TextStyle lineNumberStyle, required ValueNotifier<int> lineNumberNotifier, required bool showLineNumberIndicator, required BorderRadius borderRadius, required TextDirection textDirection, bool? thumbVisibility, bool? interactive, Color? thumbColor, double? thickness, double crossAxisMargin = 0.0, double mainAxisMargin = 0.0, ScrollbarOrientation? scrollbarOrientation, Color? trackBorderColor, Duration fadeDuration = _kScrollbarFadeDuration, Duration timeToFade = _kScrollbarTimeToFade, Radius? trackRadius, bool? trackVisibility, double? minOverscrollLength, double minThumbLength = _kMinThumbExtent, EdgeInsetsGeometry? padding, Duration pressDuration = Duration.zero, Color? trackColor, ScrollNotificationPredicate notificationPredicate = defaultScrollNotificationPredicate})
const

Properties

borderRadius BorderRadius
final
child Widget
The widget below this widget in the tree.
finalinherited
controller ScrollController?
The ScrollController used to implement Scrollbar dragging.
finalinherited
crossAxisMargin double
Distance from the scrollbar thumb's side to the nearest cross axis edge in logical pixels.
finalinherited
fadeDuration Duration
The Duration of the fade animation.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
interactive bool?
Whether the Scrollbar should be interactive and respond to dragging on the thumb, or tapping in the track area.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineNumberNotifier ValueNotifier<int>
final
lineNumberStyle TextStyle
final
mainAxisMargin double
Distance from the scrollbar thumb's start or end to the nearest edge of the viewport in logical pixels. It affects the amount of available paint area.
finalinherited
minOverscrollLength double?
The preferred smallest size the scrollbar thumb can shrink to when viewport is overscrolled.
finalinherited
minThumbLength double
The preferred smallest size the scrollbar thumb can shrink to when the total scrollable extent is large, the current visible viewport is small, and the viewport is not overscrolled.
finalinherited
notificationPredicate ScrollNotificationPredicate
A check that specifies whether a ScrollNotification should be handled by this widget.
finalinherited
padding EdgeInsetsGeometry?
The insets by which the scrollbar thumb and track should be padded.
finalinherited
pressDuration Duration
The Duration of time that a LongPress will trigger the drag gesture of the scrollbar thumb.
finalinherited
radius Radius?
The Radius of the scrollbar thumb's rounded rectangle corners.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarOrientation ScrollbarOrientation?
Dictates the orientation of the scrollbar.
finalinherited
shape OutlinedBorder?
The OutlinedBorder of the scrollbar's thumb.
finalinherited
showLineNumberIndicator bool
final
textDirection TextDirection
final
thickness double?
The thickness of the scrollbar in the cross axis of the scrollable.
finalinherited
thumbColor Color?
The color of the scrollbar thumb.
finalinherited
thumbVisibility bool?
Indicates that the scrollbar thumb should be visible, even when a scroll is not underway.
finalinherited
timeToFade Duration
The Duration of time until the fade animation begins.
finalinherited
trackBorderColor Color?
The color of the scrollbar track's border.
finalinherited
trackColor Color?
The color of the scrollbar track.
finalinherited
trackRadius Radius?
The Radius of the scrollbar track's rounded rectangle corners.
finalinherited
trackVisibility bool?
Indicates that the scrollbar track should be visible.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() RawScrollbarState<RawScrollbar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited