CodeSelectionStyle class

This class provides styling options for code selection in the code editor.

Constructors

CodeSelectionStyle({Color? cursorColor, Color selectionColor = const Color(0x6E2195F3), Color cursorBubbleColor = Colors.blue})

Properties

cursorBubbleColor → Color
The color of the cursor bubble that appears when selecting text.
final
cursorColor → Color?
The color of the cursor line, defaults to the highlight theme text color.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionColor → Color
The color used to highlight selected text in the code editor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited