DocumentHighlight class

Represents a document highlight from LSP. Used to highlight all occurrences of a symbol in the document.

Constructors

DocumentHighlight({required int startLine, required int startColumn, required int endLine, required int endColumn})
const
DocumentHighlight.fromLsp(Map<String, dynamic> data)
Creates a DocumentHighlight from LSP response data
factory

Properties

endColumn → int
The end column of the highlight (0-based)
final
endLine → int
The end line of the highlight (0-based)
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startColumn → int
The start column of the highlight (0-based)
final
startLine → int
The start line of the highlight (0-based)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited