GutterStyle class

This class provides styling options for the Gutter.

Constructors

GutterStyle({TextStyle? lineNumberStyle, Color? backgroundColor, double? gutterWidth, IconData foldedIcon = Icons.chevron_right_outlined, IconData unfoldedIcon = Icons.keyboard_arrow_down_outlined, double? foldingIconSize, Color? foldedIconColor, Color? unfoldedIconColor, Color? activeLineNumberColor, Color? inactiveLineNumberColor, Color errorLineNumberColor = const Color(0xFFE53935), Color warningLineNumberColor = const Color(0xFFFFA726), Color? foldedLineHighlightColor})

Properties

activeLineNumberColor → Color?
The color used to highlight the current line number in the gutter. If null, the line number will use the default text color.
final
backgroundColor → Color?
The background color of the gutter bar.
final
errorLineNumberColor → Color
The color used to highlight line numbers with errors (severity 1). Defaults to red.
final
foldedIcon → IconData
The icon used for the unfolded line folding indicator in the gutter.
final
foldedIconColor → Color?
The color for the folded line folding indicator icon in the gutter. Defaults to Colors.grey.
final
foldedLineHighlightColor → Color?
The background color used to highlight folded line start. If null, a low opacity version of the selection color is used.
final
foldingIconSize → double?
The size of the folding icon in the gutter. Defaults to (widget?.textStyle?.fontSize ?? 14) * 1.2.
final
gutterWidth → double?
The width of the gutter. Dynamic by default, which means it can adapt best width based on line number. So recommended to leave it null.
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveLineNumberColor → Color?
The color used for non-active line numbers in the gutter. If null, defaults to a dimmed version of the text color.
final
lineNumberStyle → TextStyle?
The style for line numbers in the gutter. Expected to be a TextStyle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unfoldedIcon → IconData
The icon used for the folded line folding indicator in the gutter.
final
unfoldedIconColor → Color?
The color for the unfolded line folding indicator icon in the gutter. Defaults to Colors.grey.
final
warningLineNumberColor → Color
The color used to highlight line numbers with warnings (severity 2). Defaults to yellow/orange.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited