displayText property
The text displayed in the IME overlay (exactly as reported by the platform). This includes any input method decorators like pinyin separators (a'a'a'a).
Implementation
final String displayText;
The text displayed in the IME overlay (exactly as reported by the platform). This includes any input method decorators like pinyin separators (a'a'a'a).
final String displayText;