SearchHighlight class

Represents a highlighted search result in the editor

Constructors

SearchHighlight({required int start, required int end, bool isCurrentMatch = false})
const

Properties

end → int
The end offset of the highlighted text
final
hashCode → int
The hash code for this object.
no setterinherited
isCurrentMatch → bool
Whether this highlight represents the currently selected match
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
The start offset of the highlighted text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited