SemanticWordSpan class

Constructors

SemanticWordSpan({required int startChar, required int endChar, required String word, required TextStyle style})

Properties

endChar → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startChar → int
final
style → TextStyle
final
word → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited