CompoundOperation class

A compound operation that groups multiple edits into one undo unit.

Inheritance

Constructors

CompoundOperation({required List<EditOperation> operations, required TextSelection selectionBefore, required TextSelection selectionAfter, List<({int character, int line})>? multiCursorsBefore, List<({int character, int line})>? multiCursorsAfter})

Properties

hashCode → int
The hash code for this object.
no setterinherited
multiCursorsAfter → List<({int character, int line})>
Secondary cursor positions after this edit (may be empty)
finalinherited
multiCursorsBefore → List<({int character, int line})>
Secondary cursor positions before this edit (may be empty)
finalinherited
operations → List<EditOperation>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionAfter → TextSelection
The cursor position after this edit
finalinherited
selectionBefore → TextSelection
The cursor position before this edit
finalinherited
timestamp → DateTime
Timestamp when this edit was made
finalinherited

Methods

canMergeWith(EditOperation other) → bool
Check if this operation can be merged with another (for grouping rapid edits)
override
inverse() → EditOperation
Create the inverse operation for undo
override
mergeWith(EditOperation other) → EditOperation
Merge this operation with another
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited