EditOperation class sealed

Represents a single edit operation that can be undone/redone. Designed to work efficiently with rope data structures.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
multiCursorsAfter → List<({int character, int line})>
Secondary cursor positions after this edit (may be empty)
final
multiCursorsBefore → List<({int character, int line})>
Secondary cursor positions before this edit (may be empty)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionAfter → TextSelection
The cursor position after this edit
final
selectionBefore → TextSelection
The cursor position before this edit
final
timestamp → DateTime
Timestamp when this edit was made
final

Methods

canMergeWith(EditOperation other) → bool
Check if this operation can be merged with another (for grouping rapid edits)
inverse() → EditOperation
Create the inverse operation for undo
mergeWith(EditOperation other) → EditOperation
Merge this operation with another
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited