code_forge/utils library

Classes

CodeForgeKeyboardShortcuts
Keyboard shortcuts used by the CodeForge. Ovrride to use your own custom shortcuts.
Defaults to:
CustomContextMenu
Create a custom entry for the context menu (The menu that appears on right click). Pass it to the CodeForge class to add the custom entry to the context menu. eg:
FoldRange
Represents a foldable code region in the editor.
GutterBuilder
Use the GutterBuilder to render custom content in the gutter. eg:
RTLAwareScrollPhysics
Custom scroll physics that reverses horizontal drag direction for RTL mode on mobile.