deletWordBackward property
Delete an entire word and moves the cursor backward.
Defaults to Ctrl + backspace
Implementation
final ShortcutActivator deletWordBackward;
Delete an entire word and moves the cursor backward.
Defaults to Ctrl + backspace
final ShortcutActivator deletWordBackward;