extendMutliCursorUpward property
Creates mutlicursor to the same column and upward rows/lines.
Implementation
final ShortcutActivator extendMutliCursorUpward;
Creates mutlicursor to the same column and upward rows/lines.
final ShortcutActivator extendMutliCursorUpward;