jumpToDocumentEndAndSelectText property

ShortcutActivator jumpToDocumentEndAndSelectText
final

Similar to jumpToDocumentEnd, place the cursor at the starting position of the current line and selecting the text from the start position to the document end. Defaults to Ctrl + Shift + end.

Implementation

final ShortcutActivator jumpToDocumentEndAndSelectText;