moveSelectionBackward property
Extends the selection backward by one character at a time. Defaults to `Shift + arrowLeft
Implementation
final ShortcutActivator moveSelectionBackward;
Extends the selection backward by one character at a time. Defaults to `Shift + arrowLeft
final ShortcutActivator moveSelectionBackward;