moveSelectionForward property
Extends the selection forward by one character at a time.
Defaults to Shift + arrowRight
Implementation
final ShortcutActivator moveSelectionForward;
Extends the selection forward by one character at a time.
Defaults to Shift + arrowRight
final ShortcutActivator moveSelectionForward;