selectToLineEnd property
Jumps the cursor to the end of the current line by selecting the line text.
Defaults to Shift + end.
Implementation
final ShortcutActivator selectToLineEnd;
Jumps the cursor to the end of the current line by selecting the line text.
Defaults to Shift + end.
final ShortcutActivator selectToLineEnd;