showFindAndReplaceBar property
Show the finder bar along with the replace bar.
Defaults to Ctrl + H
Implementation
final ShortcutActivator showFindAndReplaceBar;
Show the finder bar along with the replace bar.
Defaults to Ctrl + H
final ShortcutActivator showFindAndReplaceBar;