commitText property
The intended text to be committed if the composition is interrupted. This is determined by the Incremental Intent Tracking algorithm to distinguish between user-typed characters and IME-auto-generated characters.
Implementation
final String commitText;