menu
code_forge package
documentation
code_forge/utils.dart
code_forge/utils.dart
dark_mode
light_mode
code_forge/utils
library
Classes
CodeForgeKeyboardShortcuts
Keyboard shortcuts used by the
CodeForge
. Ovrride to use your own custom shortcuts.
Defaults to:
CustomContextMenu
Create a custom entry for the context menu (The menu that appears on right click). Pass it to the
CodeForge
class to add the custom entry to the context menu. eg:
FoldRange
Represents a foldable code region in the editor.
GutterBuilder
Use the
GutterBuilder
to render custom content in the gutter. eg:
RTLAwareScrollPhysics
Custom scroll physics that reverses horizontal drag direction for RTL mode on mobile.
code_forge package
documentation
code_forge/utils.dart
code_forge
package
Libraries
code_forge
code_forge/code_area
code_forge/controller
code_forge/find_controller
code_forge/rope
code_forge/scroll
code_forge/styling
code_forge/syntax_highlighter
code_forge/undo_redo
code_forge/utils
LSP/lsp
utils library