CodeForgeKeyboardShortcuts class

Keyboard shortcuts used by the CodeForge. Ovrride to use your own custom shortcuts.
Defaults to:

CodeForgeKeyboardShotcuts({
  this.duplicate = const SingleActivator(LogicalKeyboardKey.keyD, control: true),
  this.shiftLineUp = const SingleActivator(LogicalKeyboardKey.arrowUp, control: true, shift: true),
  this.shiftLineDown= const SingleActivator(LogicalKeyboardKey.arrowDown, control: true),
  this.deletWordBackward = const SingleActivator(LogicalKeyboardKey.backspace, control: true),
  this.deletWordForward = const SingleActivator(LogicalKeyboardKey.delete, control: true),
  this.moveCursorToNextWord = const SingleActivator(LogicalKeyboardKey.arrowRight, control: true),
  this.moveCursorToPreviousWord = const SingleActivator(LogicalKeyboardKey.arrowLeft, control: true),
  this.moveSelectionToNextWord = const SingleActivator(LogicalKeyboardKey.arrowRight, control: true, shift: true),
  this.moveSelectionToPreviousWord = const SingleActivator(LogicalKeyboardKey.arrowLeft, control: true, shift: true),
  this.lspCodeActions = const SingleActivator(LogicalKeyboardKey.period, control: true),
  this.lspSignature = const SingleActivator(LogicalKeyboardKey.space, control: true, shift: true),
  this.showFindBar = const SingleActivator(LogicalKeyboardKey.keyF, control: true),
  this.showSearchAndReplaceBar = const SingleActivator(LogicalKeyboardKey.keyH, control: true),
});

Note: The LSP inlay hints shortcut (Ctrl + Alt) is not modifiable.
Also, core operations like cut, copy, paste, select all, undo, redo aren't modifiable.

Constructors

CodeForgeKeyboardShortcuts({ShortcutActivator duplicate = const SingleActivator(LogicalKeyboardKey.keyD, control: true), ShortcutActivator shiftLineUp = const SingleActivator(LogicalKeyboardKey.arrowUp, control: true, shift: true), ShortcutActivator shiftLineDown = const SingleActivator(LogicalKeyboardKey.arrowDown, control: true, shift: true), ShortcutActivator deletWordBackward = const SingleActivator(LogicalKeyboardKey.backspace, control: true), ShortcutActivator deletWordForward = const SingleActivator(LogicalKeyboardKey.delete, control: true), ShortcutActivator moveCursorToNextWord = const SingleActivator(LogicalKeyboardKey.arrowRight, control: true), ShortcutActivator moveCursorToPreviousWord = const SingleActivator(LogicalKeyboardKey.arrowLeft, control: true), ShortcutActivator moveSelectionToNextWord = const SingleActivator(LogicalKeyboardKey.arrowRight, control: true, shift: true), ShortcutActivator moveSelectionToPreviousWord = const SingleActivator(LogicalKeyboardKey.arrowLeft, control: true, shift: true), ShortcutActivator moveSelectionUpward = const SingleActivator(LogicalKeyboardKey.arrowUp, shift: true), ShortcutActivator moveSelectionDownward = const SingleActivator(LogicalKeyboardKey.arrowDown, shift: true), ShortcutActivator moveSelectionForward = const SingleActivator(LogicalKeyboardKey.arrowRight, shift: true), ShortcutActivator moveSelectionBackward = const SingleActivator(LogicalKeyboardKey.arrowLeft, shift: true), ShortcutActivator lspCodeActions = const SingleActivator(LogicalKeyboardKey.period, control: true), ShortcutActivator lspSignatureHelp = const SingleActivator(LogicalKeyboardKey.space, control: true, shift: true), ShortcutActivator showFindBar = const SingleActivator(LogicalKeyboardKey.keyF, control: true), ShortcutActivator showFindAndReplaceBar = const SingleActivator(LogicalKeyboardKey.keyH, control: true), ShortcutActivator jumpToDocumentStart = const SingleActivator(LogicalKeyboardKey.home, control: true), ShortcutActivator jumpToDocumentEnd = const SingleActivator(LogicalKeyboardKey.end, control: true), ShortcutActivator jumpToDocumentStartAndSelectText = const SingleActivator(LogicalKeyboardKey.home, control: true, shift: true), ShortcutActivator jumpToDocumentEndAndSelectText = const SingleActivator(LogicalKeyboardKey.end, control: true, shift: true), ShortcutActivator selectToLineStart = const SingleActivator(LogicalKeyboardKey.home, shift: true), ShortcutActivator selectToLineEnd = const SingleActivator(LogicalKeyboardKey.end, shift: true), ShortcutActivator extendMutliCursorDownward = const SingleActivator(LogicalKeyboardKey.arrowDown, alt: true, shift: true), ShortcutActivator extendMutliCursorUpward = const SingleActivator(LogicalKeyboardKey.arrowUp, alt: true, shift: true)})
const

Properties

deletWordBackward ShortcutActivator
Delete an entire word and moves the cursor backward. Defaults to Ctrl + backspace
final
deletWordForward ShortcutActivator
Delete an entore word and moves the cursor forward. Defaults to Ctrl + delete
final
duplicate ShortcutActivator
Duplicate the selection, if no active selectio, current line gets duplicated. Defaults to Ctrl + D
final
extendMutliCursorDownward ShortcutActivator
Creates mutlicursor to the same column and downward rows/lines.
final
extendMutliCursorUpward ShortcutActivator
Creates mutlicursor to the same column and upward rows/lines.
final
hashCode int
The hash code for this object.
no setterinherited
jumpToDocumentEnd ShortcutActivator
Place the cursor at the starting position of the current line. Defaults to Ctrl + end
final
jumpToDocumentEndAndSelectText ShortcutActivator
Similar to jumpToDocumentEnd, place the cursor at the starting position of the current line and selecting the text from the start position to the document end. Defaults to Ctrl + Shift + end.
final
jumpToDocumentStart ShortcutActivator
Place the cursor at the starting position of the current line. Defaults to Ctrl + home
final
jumpToDocumentStartAndSelectText ShortcutActivator
Similar to jumpToDocumentStart, place the cursor at the starting position of the current line and selecting the text from the start position to the document start. Defaults to Ctrl + Shift + home.
final
lspCodeActions ShortcutActivator
Shows the LSP code actions if available. Defaults to Ctrl + .
final
lspSignatureHelp ShortcutActivator
Shows LSP signature help if available. Defaults to Ctrl + Shift + space
final
moveCursorToNextWord ShortcutActivator
Cursor jumps to the next word. Defaults to Ctrl + arrowRight
final
moveCursorToPreviousWord ShortcutActivator
Cursor jumps to the previous word. Defaults to Ctrl + arrowLeft
final
moveSelectionBackward ShortcutActivator
Extends the selection backward by one character at a time. Defaults to `Shift + arrowLeft
final
moveSelectionDownward ShortcutActivator
Extends the text selection to downward lines. Defaults tp Shift + arrowDown.
final
moveSelectionForward ShortcutActivator
Extends the selection forward by one character at a time. Defaults to Shift + arrowRight
final
moveSelectionToNextWord ShortcutActivator
Similar to moveCursorToNextWord, but selection also jumps with the cursor. Defaults to Ctrl + Shift + arrowRight
final
moveSelectionToPreviousWord ShortcutActivator
Similar to moveCursorToPreviousWord, but selection also jumps with the cursor. Defaults to Ctrl + Shift + arrowLeft
final
moveSelectionUpward ShortcutActivator
Extends the text selection to upward lines. Defaults tp Shift + arrowUp.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectToLineEnd ShortcutActivator
Jumps the cursor to the end of the current line by selecting the line text. Defaults to Shift + end.
final
selectToLineStart ShortcutActivator
Jumps the cursor to the start of the current line by selecting the line text. Defaults to Shift + home.
final
shiftLineDown ShortcutActivator
Moves the current line downwards. Defaults to Ctrl + Shift + arrowUp
final
shiftLineUp ShortcutActivator
Moves the current line upwards. Defaults to Ctrl + Shift + arrowUp
final
showFindAndReplaceBar ShortcutActivator
Show the finder bar along with the replace bar. Defaults to Ctrl + H
final
showFindBar ShortcutActivator
Show the word finder bar if provided. Defaults to Ctrl + F
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited